harmonic_average_effective_mass_mesh — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# harmonic_average_effective_mass_mesh

property ElectronicBandStructure.harmonic_average_effective_mass_mesh

  harmonic average effective mass mesh is a numpy array that stores each harmonic average effective mass mesh in a mesh grid. Shape = [n_bands,n_kx,n_ky,n_kz],

  Returns:

    np.ndarray – harmonic average effective mass mesh is a numpy array that stores each harmonic average effective mass in a mesh grid. Shape = [n_bands,n_kx,n_ky,n_kz],